@@ -1,14 +1,14 @@
 #!/usr/bin/env python
 
 import argparse, gzip, os, sys, subprocess
-from shutil import rmtree
+from shutil import rmtree, which
 from datetime import datetime
 from functools import partial
 import multiprocessing
 from copy import deepcopy
 from pysam import AlignmentFile, index
 
-__version__ = '0.6.1'
+__version__ = '1.0.1'
 
 def parseArguments():
     parser = argparse.ArgumentParser(prog='TEcount',
@@ -42,6 +42,10 @@ def run_shell_cmd(cmd):
     stdout, stdin = p.communicate(cmd)
     return stdout.strip('\n')
 
+# Small function to check whether a command is in PATH
+def check_path(cmdname):
+    return which(cmdname) is not None
+
 # Small function to write out the current date and time
 def time():
     return datetime.now().strftime("%m/%d/%Y - %H:%M:%S")
@@ -107,9 +111,9 @@ def getFeaturesDicts(bedFile, tmpdir):
             subfams.add(sfam)
             fams.add(fam)
             classes.add(clas)
-    subfams = { x: set() for x in subfams }
-    fams = { x: set() for x in fams }
-    classes = { x: set() for x in classes }
+    subfams = { x: set() for x in sorted(list(subfams)) }
+    fams = { x: set() for x in sorted(list(fams)) }
+    classes = { x: set() for x in sorted(list(classes)) }
     return subfams, fams, classes
 
 # intersect reads with features using bedtools
@@ -132,7 +136,7 @@ def isec(bamFile, bedFile, overlap, tmpdir, chr):
     cmd += f' awk \' $NF>={overlap} '
     cmd += ' { l=split($4,readid,"/"); readname=readid[1]; '
     # if single-end, set mate=1 even if no mate is recorded in read name
-    cmd += ' if(length(l)==1){mate=1}else{mate=readid[2]} '
+    cmd += ' if(l==1){mate=1}else{mate=readid[2]} '
     cmd += ' ori=($6==$12 ? "same" : "opposite"); '
     #cmd += ' ori=($6==$18 ? "same" : "opposite"); '
     cmd += ' OFS="\\t"; print readname,mate,$13,$14,$15,ori; } \' | '
@@ -244,6 +248,11 @@ def main():
     parser = parseArguments()
     args = parser.parse_args()
 
+    if not check_path('bedtools'):
+        sys.exit(f'Couldn\'t find bedtools in PATH. Please install bedtools and try again.')
+    if not check_path('samtools'):
+        sys.exit(f'Couldn\'t find samtools in PATH. Please install samtools and try again.')
+
     checkIndex(args.bam)
 
     chrNames = getRefs(args.bam, args.tmpdir)
